/*
 * @Description: markdown 转化
 */
import { getTransformValue } from './transform';
export * from './interface';
import remark from 'remark';
/** 转换 代码*/

var getProcessor = scope => {
  var child = remark.parse(scope);
  return child.children;
};

var getMeta = meta => {
  var metaData = {};

  if (meta) {
    var [metaItem] = /mdx:(.[\w|:]+)/i.exec(meta) || [];
    var [_, field, val] = (metaItem || '').split(':').map(item => item.trim());
    metaData[field] = val || true;
  }

  return metaData;
};
/** 获取需要渲染的代码块 **/


var getCodeBlock = function getCodeBlock(child, lang) {
  if (lang === void 0) {
    lang = ['jsx', 'tsx'];
  }

  // 获取渲染部分
  var codeBlock = {};
  child.forEach(item => {
    if (item && item.type === 'code' && lang.includes(item.lang)) {
      var line = item.position.start.line;
      var metaData = getMeta(item.meta);

      if (metaData.preview) {
        var name = typeof metaData.preview === 'string' ? metaData.preview : line;
        var funName = "BaseCode" + line;
        var returnCode = getTransformValue(item.value, funName + "." + lang, funName);
        codeBlock[line] = {
          code: returnCode,
          name,
          language: item.lang,
          value: item.value
        };
      }
    }
  });
  return codeBlock;
};

var createStr = codeBlock => {
  var baseCodeStr = "";
  var baseCodeObjStr = "";
  var codeBlockValue = "";
  var languageStr = "";
  Object.entries(codeBlock).forEach(_ref => {
    var [key, item] = _ref;
    var {
      code,
      value,
      language,
      name
    } = item;
    baseCodeStr += code + ";\n";
    baseCodeObjStr += name + ":BaseCode" + key + ",\n";
    codeBlockValue += name + ":" + JSON.stringify(value) + ",\n";
    languageStr += name + ":`" + language + "`,\n";
  });
  var indexStr = baseCodeStr + " const languages={" + languageStr + "};\n const codeBlock={" + codeBlockValue + "};\n const components={" + baseCodeObjStr + "}";
  return indexStr;
};

export var getCodeBlockString = function getCodeBlockString(scope, lang) {
  if (lang === void 0) {
    lang = ['jsx', 'tsx'];
  }

  var children = getProcessor(scope);
  var codeBlock = getCodeBlock(children, lang);
  var result = createStr(codeBlock);
  return result;
};
/**
 * 配置好markdown的loader
 * @param {webpack.Configuration} config webpack配置
 * @param {string[]} lang 解析语言
 * @returns {webpack.Configuration}
 * **/

export var mdCodeModulesLoader = (config, lang) => {
  config.module.rules.forEach(ruleItem => {
    if (typeof ruleItem === 'object') {
      if (ruleItem.oneOf) {
        ruleItem.oneOf.unshift({
          test: /.md$/,
          use: [{
            loader: 'markdown-react-code-preview-loader',
            options: {
              lang
            }
          }]
        });
      }
    }
  });
  return config;
};
//# sourceMappingURL=index.js.map