"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault")["default"];

Object.defineProperty(exports, "__esModule", {
  value: true
});
var _exportNames = {
  getCodeBlockString: true,
  mdCodeModulesLoader: true
};
exports.mdCodeModulesLoader = exports.getCodeBlockString = void 0;

var _typeof2 = _interopRequireDefault(require("@babel/runtime/helpers/typeof"));

var _slicedToArray2 = _interopRequireDefault(require("@babel/runtime/helpers/slicedToArray"));

var _transform = require("./transform");

var _interface = require("./interface");

Object.keys(_interface).forEach(function (key) {
  if (key === "default" || key === "__esModule") return;
  if (Object.prototype.hasOwnProperty.call(_exportNames, key)) return;
  if (key in exports && exports[key] === _interface[key]) return;
  Object.defineProperty(exports, key, {
    enumerable: true,
    get: function get() {
      return _interface[key];
    }
  });
});

var _remark = _interopRequireDefault(require("remark"));

/*
 * @Description: markdown 转化
 */

/** 转换 代码*/
var getProcessor = function getProcessor(scope) {
  var child = _remark["default"].parse(scope);

  return child.children;
};

var getMeta = function getMeta(meta) {
  var metaData = {};

  if (meta) {
    var _ref = /mdx:(.[\w|:]+)/i.exec(meta) || [],
        _ref2 = (0, _slicedToArray2["default"])(_ref, 1),
        metaItem = _ref2[0];

    var _split$map = (metaItem || '').split(':').map(function (item) {
      return item.trim();
    }),
        _split$map2 = (0, _slicedToArray2["default"])(_split$map, 3),
        _ = _split$map2[0],
        field = _split$map2[1],
        val = _split$map2[2];

    metaData[field] = val || true;
  }

  return metaData;
};
/** 获取需要渲染的代码块 **/


var getCodeBlock = function getCodeBlock(child) {
  var lang = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : ['jsx', 'tsx'];
  // 获取渲染部分
  var codeBlock = {};
  child.forEach(function (item) {
    if (item && item.type === 'code' && lang.includes(item.lang)) {
      var line = item.position.start.line;
      var metaData = getMeta(item.meta);

      if (metaData.preview) {
        var name = typeof metaData.preview === 'string' ? metaData.preview : line;
        var funName = "BaseCode".concat(line);
        var returnCode = (0, _transform.getTransformValue)(item.value, "".concat(funName, ".").concat(lang), funName);
        codeBlock[line] = {
          code: returnCode,
          name: name,
          language: item.lang,
          value: item.value
        };
      }
    }
  });
  return codeBlock;
};

var createStr = function createStr(codeBlock) {
  var baseCodeStr = "";
  var baseCodeObjStr = "";
  var codeBlockValue = "";
  var languageStr = "";
  Object.entries(codeBlock).forEach(function (_ref3) {
    var _ref4 = (0, _slicedToArray2["default"])(_ref3, 2),
        key = _ref4[0],
        item = _ref4[1];

    var code = item.code,
        value = item.value,
        language = item.language,
        name = item.name;
    baseCodeStr += "".concat(code, ";\n");
    baseCodeObjStr += "".concat(name, ":BaseCode").concat(key, ",\n");
    codeBlockValue += "".concat(name, ":").concat(JSON.stringify(value), ",\n");
    languageStr += "".concat(name, ":`").concat(language, "`,\n");
  });
  var indexStr = "".concat(baseCodeStr, " const languages={").concat(languageStr, "};\n const codeBlock={").concat(codeBlockValue, "};\n const components={").concat(baseCodeObjStr, "}");
  return indexStr;
};

var getCodeBlockString = function getCodeBlockString(scope) {
  var lang = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : ['jsx', 'tsx'];
  var children = getProcessor(scope);
  var codeBlock = getCodeBlock(children, lang);
  var result = createStr(codeBlock);
  return result;
};
/**
 * 配置好markdown的loader
 * @param {webpack.Configuration} config webpack配置
 * @param {string[]} lang 解析语言
 * @returns {webpack.Configuration}
 * **/


exports.getCodeBlockString = getCodeBlockString;

var mdCodeModulesLoader = function mdCodeModulesLoader(config, lang) {
  config.module.rules.forEach(function (ruleItem) {
    if ((0, _typeof2["default"])(ruleItem) === 'object') {
      if (ruleItem.oneOf) {
        ruleItem.oneOf.unshift({
          test: /.md$/,
          use: [{
            loader: 'markdown-react-code-preview-loader',
            options: {
              lang: lang
            }
          }]
        });
      }
    }
  });
  return config;
};

exports.mdCodeModulesLoader = mdCodeModulesLoader;
//# sourceMappingURL=index.js.map